.. _physics_tutorials:

=================
Physics Tutorials
=================

The Physics Tutorials aim to introduce SymPy to users who have not previously
used its physics features. The functionalities presented here have many more
options and capabilities than what is covered in the tutorials.  Through
insightful examples and exercises, the tutorials demonstrate how to incorporate
various physics subpackages of SymPy, including but not limited to multibody
dynamics, quantum mechanics, optics, and continuum mechanics, to model and
simulate different physical systems and their behaviors.

Feedback on this tutorial, or on SymPy in general is always welcome. Just write
to our `mailing list
<https://groups.google.com/forum/?fromgroups#!forum/sympy>`_.

**Content**

.. toctree::
   :maxdepth: 2

   biomechanics/index.rst
